# Orwynn
... documentation is in process of writing. Take some coffee!

## Environment variables
### ... in process of writing

### ORWYNN_IS_CATCH_LOGGING_ENABLED_IN_TESTS
Whether the error handlers should catch+log+reraise incoming errors in test
mode. Defaults to False to not pollute stderr on testing.
